Kytos - Administrative Interface
Author: Kytos Team
Description: Kytos administrative interface

#### Save this layout

Terminal content
Click on an element on the topology chart to show its context here.
Notifications

# Display elements:

Select the elements to be displayed

Topology Unused interfaces Disconnected hosts

# Layout Settings

Save and restore layouts.

# Label Settings

Select which labels you want to show.

Switch:
Host:
Address Name

# Other Settings

,,,

Show Map
Enable Logs